summaryrefslogtreecommitdiffstats
path: root/kalarm/sounddlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/sounddlg.cpp')
-rw-r--r--kalarm/sounddlg.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kalarm/sounddlg.cpp b/kalarm/sounddlg.cpp
index d1cd97887..77894b7a7 100644
--- a/kalarm/sounddlg.cpp
+++ b/kalarm/sounddlg.cpp
@@ -119,8 +119,8 @@ SoundDlg::SoundDlg(const TQString& file, float volume, float fadeVolume, int fad
int indentWidth = 3 * KDialog::spacingHint();
grid->addColSpacing(0, indentWidth);
grid->addColSpacing(1, indentWidth);
- // Get tqalignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
- int tqalignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
+ // Get alignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
+ int alignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
// 'Set volume' checkbox
box = new TQHBox(group);
@@ -146,12 +146,12 @@ SoundDlg::SoundDlg(const TQString& file, float volume, float fadeVolume, int fad
connect(mFadeCheckbox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotFadeToggled(bool)));
TQWhatsThis::add(mFadeCheckbox,
i18n("Select to fade the volume when the sound file first starts to play."));
- grid->addMultiCellWidget(mFadeCheckbox, 2, 2, 1, 2, tqalignment);
+ grid->addMultiCellWidget(mFadeCheckbox, 2, 2, 1, 2, alignment);
// Fade time
mFadeBox = new TQHBox(group);
mFadeBox->setSpacing(spacingHint());
- grid->addWidget(mFadeBox, 3, 2, tqalignment);
+ grid->addWidget(mFadeBox, 3, 2, alignment);
TQLabel* label = new TQLabel(i18n("Time period over which to fade the sound", "Fade time:"), mFadeBox);
label->setFixedSize(label->sizeHint());
mFadeTime = new SpinBox(1, 999, 1, mFadeBox);
@@ -299,7 +299,7 @@ void SoundDlg::playSound()
|| !KIO::NetAccess::download(url, mLocalAudioFile, mmw))
{
kdError(5950) << "SoundDlg::playAudio(): Open failure: " << mFileName << endl;
- KMessageBox::error(this, i18n("Cannot open audio file:\n%1").tqarg(mFileName));
+ KMessageBox::error(this, i18n("Cannot open audio file:\n%1").arg(mFileName));
return;
}
mPlayTimer = new TQTimer(this);